### Django ###
*.log
*.pot
*.pyc
__pycache__/

# ide
.idea/

# hidden files
.*
!.gitignore
!.editorconfig

# celery
celerybeat.pid

# static generated
static_root/

# virtual env
venv

.doc

settings/local.py
settings/dev.local.py
