# EditorConfig is awesome

# top-most EditorConfig file
root = true

# Unix-style newlines with a newline ending every file
[*]
end_of_line = lf
insert_final_newline = true

# Matches multiple files with brace expansion notation
[*.{js,html,css}]
charset = utf-8
indent_style = space
tab_width = 2

[*.py]
max_line_length = 100

